@@ -2,4 +2,4 @@ from .modules.profile import Profile
 from .modules.tweets import get_tweets
 from .modules.trends import get_trends
 
-__all__ = ['Profile', 'get_tweets', 'get_trends']
+__all__ = ["Profile", "get_tweets", "get_trends"]
