@@ -26,11 +26,7 @@ class Profile:
             - user_id
     """
 
-    def __init__(self, username=None, id=None):
-        breakpoint()
-        if not username and not id:
-            raise ValueError("Username or id required!")
-
+    def __init__(self, username):
         headers = {
             "Accept": "application/json, text/javascript, */*; q=0.01",
             "Referer": f"https://twitter.com/{username}",
@@ -40,11 +36,7 @@ class Profile:
             "Accept-Language": "en-US",
         }
 
-        if id:
-            page = session.get(f"https://twitter.com/i/user/{id}", headers=headers)
-        
         page = session.get(f"https://twitter.com/{username}", headers=headers)
-        
         self.username = username
         self.__parse_profile(page)
 
